@@ -1,20 +1,20 @@
 
 module Config
 
-  VERSION == "1.4.3" or
-    raise "ruby lib version (1.4.3) doesn't match executable version (#{VERSION})"
+  VERSION == "1.4.6" or
+    raise "ruby lib version (1.4.6) doesn't match executable version (#{VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   CONFIG = {}
-  CONFIG["srcdir"] = "/usr/ports/lang/ruby/work/ruby-1.4.3"
+  CONFIG["srcdir"] = "/usr/ports/lang/ruby/work/ruby-1.4.6"
   CONFIG["prefix"] = "/usr/local"
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ""
   CONFIG["SHELL"] = "/bin/sh"
   CONFIG["CFLAGS"] = "-O2    -fPIC"
   CONFIG["CPPFLAGS"] = ""
-  CONFIG["CXXFLAGS"] = ""
+  CONFIG["CXXFLAGS"] = "-O2   "
   CONFIG["FFLAGS"] = ""
   CONFIG["LDFLAGS"] = ""
   CONFIG["LIBS"] = "-lm "
@@ -33,12 +33,12 @@ module Config
   CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "3"
-  CONFIG["host"] = "i386-unknown-openbsd2.7"
-  CONFIG["host_alias"] = "i386-unknown-openbsd2.7"
+  CONFIG["TEENY"] = "6"
+  CONFIG["host"] = "i386-unknown-openbsd2.8"
+  CONFIG["host_alias"] = "i386-unknown-openbsd2.8"
   CONFIG["host_cpu"] = "i386"
   CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_os"] = "openbsd2.7"
+  CONFIG["host_os"] = "openbsd2.8"
   CONFIG["CC"] = "cc"
   CONFIG["CPP"] = "cc -E"
   CONFIG["YACC"] = "yacc"
@@ -68,9 +68,10 @@ module Config
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
   CONFIG["SOLIBS"] = ""
-  CONFIG["arch"] = "i386-openbsd2.7"
+  CONFIG["arch"] = "i386-openbsd2.8"
+  CONFIG["sitedir"] = "/usr/local/lib/ruby/site_ruby"
   CONFIG["configure_args"] = "--enable-shared --with-tcl-include=/usr/local/include/tcl8.3 --with-tk-include=/usr/local/include/tk8.3 --with-X11-dir=/usr/X11R6 --prefix=/usr/local --sysconfdir=/etc"
-  CONFIG["compile_dir"] = "/usr/ports/lang/ruby/work/build-i386"
+  CONFIG["compile_dir"] = "/usr/obj/ports/lang/ruby/build-i386"
   CONFIG.each_value do |val|
     val.gsub!(/\$\(([^()]+)\)/) do |var|
       key = $1
