@@ -82,16 +82,16 @@
 #define HAVE_SIGACTION 1
 #define HAVE__SETJMP 1
 #define HAVE_SETSID 1
-#define HAVE_MKSTEMP 1
 #define HAVE_TM_ZONE 1
 #define POSIX_SIGNAL 1
 #define GETPGRP_VOID 1
 #define WORDS_BIGENDIAN 1
-#define RSHIFT(x,y) ((x)>>y)
+#define RSHIFT(x,y) ((x)>>(int)y)
 #define FILE_COUNT _r
 #define DLEXT ".so"
 #define RUBY_LIB "/usr/local/lib/ruby/1.4"
-#define RUBY_SITE_LIB "/usr/local/lib/ruby/1.4/site_ruby"
-#define RUBY_PLATFORM "sparc-openbsd2.7"
-#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.4/sparc-openbsd2.7"
-#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/1.4/site_ruby/sparc-openbsd2.7"
+#define RUBY_SITE_LIB "/usr/local/lib/ruby/site_ruby"
+#define RUBY_SITE_LIB2 "/usr/local/lib/ruby/site_ruby/1.4"
+#define RUBY_PLATFORM "sparc-openbsd2.8"
+#define RUBY_ARCHLIB "/usr/local/lib/ruby/1.4/sparc-openbsd2.8"
+#define RUBY_SITE_ARCHLIB "/usr/local/lib/ruby/site_ruby/1.4/sparc-openbsd2.8"
